function Analyze( inResults, inGTs )
% ANALYZE analizes the results for room detection and setores in a xls
% file.
% 
% INPUT / OUTPUT
%   IMRESULTS is the folder where the detections of the rooms are located
%   for all the plans.
%   IMGTS is the folder where all the ground truth images are located.
%   OUTXLSNAME1 is the folder where this procedure stores a xls file
%   containing the results


%matlabpool open 1;

outFolder = [pwd '/Results'];

if ~exist(outFolder,'dir'),
    mkdir(outFolder);
end

dircontent=dir(inResults);
foldernames=dircontent(3:size(dircontent,1));

outxlsname1 = [outFolder '/parallel'];

%% Image reading
for i=1:size(foldernames,1),
    if foldernames(i).isdir,
        foldername = foldernames(i).name;
        outxlsname = [outxlsname1 foldername];
        
        dircontent=dir([inResults '/' foldername]);
        filenames=dircontent(3:size(dircontent,1));
        
        B = cell(size(foldernames,1),11);
        B(1,:) = {'IMAGENAME','RECOGNITION ACC','DETECTION RATE','d_many2one',...
            'd_one2many','g_many2one','g_one2many','ONE2ONE rate',...
            'gt_instances','r_instances','one2one_mX'};
       
        for j=1:size(filenames,1),
            
            % names of the files
            nameOriginal = filenames(j).name;
            nameGT = [nameOriginal(1:end-4) '-Room.png'];
            
            % read the images
            if ~strcmp(nameOriginal(end-3:end),'.png'),
                nameOriginal(end-3:end) = '.png';
            end
            
            imResult = logical(imread([inResults foldername '/' nameOriginal]));
            if sum(sum(imResult==0))<sum(sum(imResult==1)),
                imResult = ~imResult;
            end
            
            imGT = logical(imread([inGTs '/' nameGT]));
            if sum(sum(imGT==0))<sum(sum(imGT==1)),
                imGT = ~imGT;
            end
            
            % resize the result image if has not the same size to the
            % original and GT
            
            if sum(size(imResult) == size(imGT)) < 2,
                se = strel('square',2);
                imResult = imerode(imResult,se);
                imResult = imresize(imResult,size(imGT));
            end
            
            % get the quantitative results
            results = getResults(imResult,imGT);
            B(j+1,:) = {nameOriginal,results{1},results{2},results{3},results{4},...
                results{5},results{6},results{7},results{8},results{9},results{10}};
        end
        
        xlswrite(outxlsname,B);
    end
    
end
