% This script evaluates using Jaccard Index JI the results obtained
% compared to the GT of any kind of element. The Original images has to be
% stored in the folder "Original". These images are used to control that
% the size of the original image and the results one are the same. The
% results obtained are stored as images in the folder "Results". The
% ground-truth images should be stored in a folder called "GT". Notice that pixels belonging to
% the object should be represented by ones, and background by 0.

wallResults = struct('TP',0,'FP',0,'TN',0,'FN',0,'precision',0,'recall',0);

%% read the images in the folders

% read the original images
dircontent=dir('./Original');
fnamesO=dircontent(3:size(dircontent,1));
clear dircontent;

% read the result images
dircontent=dir('./Results');
fnamesR=dircontent(3:size(dircontent,1));
clear dircontent;

% read the GT images
dircontent=dir('./GT');
fnamesGT=dircontent(3:size(dircontent,1));
clear dircontent;

% check if there is the same number of elements in each folder
if (size(fnamesO,1) ~= size(fnamesR,1)) || (size(fnamesR,1) ~= size(fnamesGT,1)),
    clear fnames0;
end


%% for every result image
for n=1:size(fnamesO,1)
    % get the image name
    name = fnamesO(n).name;
    nameWithoutExtension=name(1:size(name,2)-4);
    % read the original image
    cd ./Original;
    oImage = logical(imread(name));
    originalImage = not(reshape(oImage(:,:,1),size(oImage,1),[]));
    % read the result image
    cd(['../Results/' nameWithoutExtension '.jpg/']);
    rImage = logical(imread('walls.png'));
    resultsImage = not(reshape(rImage(:,:,1),size(rImage,1),[]));
    % read the gtimage
    cd ../../GT;
    gtImage = logical(imread([nameWithoutExtension '-Wall.png']));
    cd ..;
    
    % check if the original image has the same size as the result image
    if sum(size(originalImage) == size(resultsImage)) ~= 2,
        imRescaled = imresize(resultsImage,size(originalImage),'bilinear');
    else
        imRescaled = resultsOriginal;
    end
    
    % final results evaluation
    classTP = and(and(imRescaled,gtImage),originalImage);
    classTN = and(and(not(imRescaled),not(gtImage)),not(originalImage));
    classFP = and(and(imRescaled,not(gtImage)),originalImage);
    classFN = and(and(not(imRescaled),gtImage),originalImage);
    
    wallResults(n).TP = sum(sum(classTP));
    wallResults(n).FP = sum(sum(classFP));
    wallResults(n).TN = sum(sum(classTN));
    wallResults(n).FN = sum(sum(classFN));
    wallResults(n).precision = wallResults(n).TP/(wallResults(n).TP + wallResults(n).FP);
    wallResults(n).recall = wallResults(n).TP/(wallResults(n).TP + wallResults(n).FN);
    wallResults(n).pascal = wallResults(n).TP/(wallResults(n).TP + wallResults(n).FP + wallResults(n).FN);
    
    clear classTP classTN classFP classFN;
end

totalP = 0;
totalR = 0;
totalPasc = 0;

for i=1:size(wallResults,2),
    totalP = wallResults(i).precision + totalP;
    totalR = wallResults(i).recall + totalR;
    totalPasc = wallResults(i).pascal + totalPasc;
end

globalPrecision = totalP / size(wallResults,2);
globalRecall = totalR / size(wallResults,2);
globalPascal = totalPasc / size(wallResults,2);
